Calculate relative humidity from temperature and dewpoint
Source:R/heat_stress.R
relative_humidity_from_dewpoint.RdUses the Magnus-Tetens approximation to calculate relative humidity from air temperature and dewpoint temperature.

R/heat_stress.R
relative_humidity_from_dewpoint.RdUses the Magnus-Tetens approximation to calculate relative humidity from air temperature and dewpoint temperature.