This module defines which ERA5 variables should use specific aggregation methods when performing temporal aggregation (daily, monthly, yearly).
This module defines which ERA5 variables should use specific aggregation methods when performing temporal aggregation (daily, monthly, yearly).